@@ -1,3 +1,5 @@
+from typing import Any, Dict
+
 from cognite.client.data_classes._base import CogniteResponse
 
 
@@ -20,7 +22,7 @@ class LoginStatus(CogniteResponse):
         self.api_key_id = api_key_id
 
     @classmethod
-    def _load(cls, api_response):
+    def _load(cls, api_response: Dict[str, Any]) -> "LoginStatus":
         data = api_response["data"]
         return cls(
             user=data["user"],
